# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.app_url_input import AppUrlInput
from flowhunt.models.bool_char import BoolChar
from flowhunt.models.schedule_frequency import ScheduleFrequency
from flowhunt.models.schedule_type import ScheduleType
from typing import Optional, Set
from typing_extensions import Self

class ScheduleCreateRequest(BaseModel):
    """
    ScheduleCreateRequest
    """ # noqa: E501
    url: AppUrlInput
    frequency: ScheduleFrequency
    schedule_type: ScheduleType
    with_screenshot: Optional[BoolChar] = None
    with_browser: Optional[BoolChar] = None
    follow_links: Optional[BoolChar] = None
    with_proxy_rotation: Optional[BoolChar] = None
    disallow_urls: Optional[StrictStr] = None
    filter_urls: Optional[StrictStr] = None
    custom_headers: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["url", "frequency", "schedule_type", "with_screenshot", "with_browser", "follow_links", "with_proxy_rotation", "disallow_urls", "filter_urls", "custom_headers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScheduleCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of url
        if self.url:
            _dict['url'] = self.url.to_dict()
        # set to None if with_screenshot (nullable) is None
        # and model_fields_set contains the field
        if self.with_screenshot is None and "with_screenshot" in self.model_fields_set:
            _dict['with_screenshot'] = None

        # set to None if with_browser (nullable) is None
        # and model_fields_set contains the field
        if self.with_browser is None and "with_browser" in self.model_fields_set:
            _dict['with_browser'] = None

        # set to None if follow_links (nullable) is None
        # and model_fields_set contains the field
        if self.follow_links is None and "follow_links" in self.model_fields_set:
            _dict['follow_links'] = None

        # set to None if with_proxy_rotation (nullable) is None
        # and model_fields_set contains the field
        if self.with_proxy_rotation is None and "with_proxy_rotation" in self.model_fields_set:
            _dict['with_proxy_rotation'] = None

        # set to None if disallow_urls (nullable) is None
        # and model_fields_set contains the field
        if self.disallow_urls is None and "disallow_urls" in self.model_fields_set:
            _dict['disallow_urls'] = None

        # set to None if filter_urls (nullable) is None
        # and model_fields_set contains the field
        if self.filter_urls is None and "filter_urls" in self.model_fields_set:
            _dict['filter_urls'] = None

        # set to None if custom_headers (nullable) is None
        # and model_fields_set contains the field
        if self.custom_headers is None and "custom_headers" in self.model_fields_set:
            _dict['custom_headers'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScheduleCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "url": AppUrlInput.from_dict(obj["url"]) if obj.get("url") is not None else None,
            "frequency": obj.get("frequency"),
            "schedule_type": obj.get("schedule_type"),
            "with_screenshot": obj.get("with_screenshot"),
            "with_browser": obj.get("with_browser"),
            "follow_links": obj.get("follow_links"),
            "with_proxy_rotation": obj.get("with_proxy_rotation"),
            "disallow_urls": obj.get("disallow_urls"),
            "filter_urls": obj.get("filter_urls"),
            "custom_headers": obj.get("custom_headers")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.schedule_url_detail_response import ScheduleUrlDetailResponse

class TestScheduleUrlDetailResponse(unittest.TestCase):
    """ScheduleUrlDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScheduleUrlDetailResponse:
        """Test ScheduleUrlDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScheduleUrlDetailResponse`
        """
        model = ScheduleUrlDetailResponse()
        if include_optional:
            return ScheduleUrlDetailResponse(
                schedule_id = '',
                domain_id = '',
                url_id = '',
                url = '',
                last_text_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                page_screenshot = flowhunt.models.url_screenshot_response.UrlScreenshotResponse(
                    original_image = '', 
                    thumbnail_image = '', 
                    original_image_full_page = '', 
                    thumbnail_image_full_page = '', ),
                url_title = '',
                url_meta_description = '',
                url_og_image = '',
                is_original_url = True,
                dest_url_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                url_text = [
                    {
                        'key' : ''
                        }
                    ]
            )
        else:
            return ScheduleUrlDetailResponse(
                schedule_id = '',
                domain_id = '',
                url_id = '',
                url = '',
                last_text_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                page_screenshot = flowhunt.models.url_screenshot_response.UrlScreenshotResponse(
                    original_image = '', 
                    thumbnail_image = '', 
                    original_image_full_page = '', 
                    thumbnail_image_full_page = '', ),
                url_title = '',
                url_meta_description = '',
                url_og_image = '',
                is_original_url = True,
                dest_url_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                url_text = [
                    {
                        'key' : ''
                        }
                    ],
        )
        """

    def testScheduleUrlDetailResponse(self):
        """Test ScheduleUrlDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.prompt_create_request import PromptCreateRequest

class TestPromptCreateRequest(unittest.TestCase):
    """PromptCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PromptCreateRequest:
        """Test PromptCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PromptCreateRequest`
        """
        model = PromptCreateRequest()
        if include_optional:
            return PromptCreateRequest(
                cat_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                name = 'example.pdf',
                description = '',
                prompt_text = 'Prompt text',
                prompt_url = flowhunt.models.app_url.AppUrl(
                    parsed_url = [
                        null
                        ], 
                    url = '', )
            )
        else:
            return PromptCreateRequest(
                cat_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                name = 'example.pdf',
                prompt_text = 'Prompt text',
        )
        """

    def testPromptCreateRequest(self):
        """Test PromptCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.secrets_api import SecretsApi


class TestSecretsApi(unittest.TestCase):
    """SecretsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SecretsApi()

    def tearDown(self) -> None:
        pass

    def test_create_secret(self) -> None:
        """Test case for create_secret

        Create Secret
        """
        pass

    def test_delete_secret(self) -> None:
        """Test case for delete_secret

        Delete Secret
        """
        pass

    def test_get_secret(self) -> None:
        """Test case for get_secret

        Get Secret
        """
        pass

    def test_search_secret(self) -> None:
        """Test case for search_secret

        Search Secret
        """
        pass

    def test_update_secret(self) -> None:
        """Test case for update_secret

        Update Secret
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.google_ads_keyword_recommendation import GoogleAdsKeywordRecommendation

class TestGoogleAdsKeywordRecommendation(unittest.TestCase):
    """GoogleAdsKeywordRecommendation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleAdsKeywordRecommendation:
        """Test GoogleAdsKeywordRecommendation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleAdsKeywordRecommendation`
        """
        model = GoogleAdsKeywordRecommendation()
        if include_optional:
            return GoogleAdsKeywordRecommendation(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                campaign_name = '',
                group_id = '',
                group_name = '',
                keyword_id = '',
                keyword = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                recommendations = [
                    flowhunt.models.google_ads_recommendation.GoogleAdsRecommendation(
                        recommendation_type = 'A', 
                        campaign_id = '', 
                        campaign_name = '', 
                        group_id = '', 
                        group_name = '', 
                        action_status = 'E', 
                        confidence = 'H', )
                    ]
            )
        else:
            return GoogleAdsKeywordRecommendation(
                workspace_id = '',
                customer_id = '',
                campaign_id = '',
                campaign_name = '',
                group_id = '',
                group_name = '',
                keyword_id = '',
                keyword = '',
        )
        """

    def testGoogleAdsKeywordRecommendation(self):
        """Test GoogleAdsKeywordRecommendation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.documents_api import DocumentsApi


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DocumentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_document_category(self) -> None:
        """Test case for create_document_category

        Create Document Category
        """
        pass

    def test_create_faq(self) -> None:
        """Test case for create_faq

        Create Faq
        """
        pass

    def test_delete_document(self) -> None:
        """Test case for delete_document

        Delete Document
        """
        pass

    def test_delete_document_category(self) -> None:
        """Test case for delete_document_category

        Delete Document Category
        """
        pass

    def test_delete_faq(self) -> None:
        """Test case for delete_faq

        Delete Faq
        """
        pass

    def test_download_binary_document(self) -> None:
        """Test case for download_binary_document

        Download Binary Document
        """
        pass

    def test_download_text_document(self) -> None:
        """Test case for download_text_document

        Download Text Document
        """
        pass

    def test_import_faq(self) -> None:
        """Test case for import_faq

        Import Faq
        """
        pass

    def test_search_document_categories(self) -> None:
        """Test case for search_document_categories

        Search Document Categories
        """
        pass

    def test_search_documents(self) -> None:
        """Test case for search_documents

        Search Documents
        """
        pass

    def test_search_faqs(self) -> None:
        """Test case for search_faqs

        Search Faqs
        """
        pass

    def test_update_document(self) -> None:
        """Test case for update_document

        Update Document
        """
        pass

    def test_update_document_category(self) -> None:
        """Test case for update_document_category

        Update Document Category
        """
        pass

    def test_update_faq(self) -> None:
        """Test case for update_faq

        Update Faq
        """
        pass

    def test_upload_document(self) -> None:
        """Test case for upload_document

        Upload Document
        """
        pass

    def test_upload_from_url_document(self) -> None:
        """Test case for upload_from_url_document

        Upload From Url Document
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.app_url_output import AppUrlOutput
from flowhunt.models.task_status import TaskStatus
from typing import Optional, Set
from typing_extensions import Self

class ScreenshotResponse(BaseModel):
    """
    ScreenshotResponse
    """ # noqa: E501
    id: StrictStr = Field(description="Task ID")
    status: TaskStatus = Field(description="Task status")
    result: Optional[StrictStr] = None
    error_message: Optional[StrictStr] = None
    original_size_url: Optional[AppUrlOutput] = None
    thumbnail_url: Optional[AppUrlOutput] = None
    original_size_url_full_page: Optional[AppUrlOutput] = None
    thumbnail_url_full_page: Optional[AppUrlOutput] = None
    timestamp: Optional[StrictInt] = None
    domain_id: Optional[StrictStr] = None
    url_id: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "status", "result", "error_message", "original_size_url", "thumbnail_url", "original_size_url_full_page", "thumbnail_url_full_page", "timestamp", "domain_id", "url_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScreenshotResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of original_size_url
        if self.original_size_url:
            _dict['original_size_url'] = self.original_size_url.to_dict()
        # override the default output from pydantic by calling `to_dict()` of thumbnail_url
        if self.thumbnail_url:
            _dict['thumbnail_url'] = self.thumbnail_url.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_size_url_full_page
        if self.original_size_url_full_page:
            _dict['original_size_url_full_page'] = self.original_size_url_full_page.to_dict()
        # override the default output from pydantic by calling `to_dict()` of thumbnail_url_full_page
        if self.thumbnail_url_full_page:
            _dict['thumbnail_url_full_page'] = self.thumbnail_url_full_page.to_dict()
        # set to None if result (nullable) is None
        # and model_fields_set contains the field
        if self.result is None and "result" in self.model_fields_set:
            _dict['result'] = None

        # set to None if error_message (nullable) is None
        # and model_fields_set contains the field
        if self.error_message is None and "error_message" in self.model_fields_set:
            _dict['error_message'] = None

        # set to None if original_size_url (nullable) is None
        # and model_fields_set contains the field
        if self.original_size_url is None and "original_size_url" in self.model_fields_set:
            _dict['original_size_url'] = None

        # set to None if thumbnail_url (nullable) is None
        # and model_fields_set contains the field
        if self.thumbnail_url is None and "thumbnail_url" in self.model_fields_set:
            _dict['thumbnail_url'] = None

        # set to None if original_size_url_full_page (nullable) is None
        # and model_fields_set contains the field
        if self.original_size_url_full_page is None and "original_size_url_full_page" in self.model_fields_set:
            _dict['original_size_url_full_page'] = None

        # set to None if thumbnail_url_full_page (nullable) is None
        # and model_fields_set contains the field
        if self.thumbnail_url_full_page is None and "thumbnail_url_full_page" in self.model_fields_set:
            _dict['thumbnail_url_full_page'] = None

        # set to None if timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.timestamp is None and "timestamp" in self.model_fields_set:
            _dict['timestamp'] = None

        # set to None if domain_id (nullable) is None
        # and model_fields_set contains the field
        if self.domain_id is None and "domain_id" in self.model_fields_set:
            _dict['domain_id'] = None

        # set to None if url_id (nullable) is None
        # and model_fields_set contains the field
        if self.url_id is None and "url_id" in self.model_fields_set:
            _dict['url_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScreenshotResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "status": obj.get("status"),
            "result": obj.get("result"),
            "error_message": obj.get("error_message"),
            "original_size_url": AppUrlOutput.from_dict(obj["original_size_url"]) if obj.get("original_size_url") is not None else None,
            "thumbnail_url": AppUrlOutput.from_dict(obj["thumbnail_url"]) if obj.get("thumbnail_url") is not None else None,
            "original_size_url_full_page": AppUrlOutput.from_dict(obj["original_size_url_full_page"]) if obj.get("original_size_url_full_page") is not None else None,
            "thumbnail_url_full_page": AppUrlOutput.from_dict(obj["thumbnail_url_full_page"]) if obj.get("thumbnail_url_full_page") is not None else None,
            "timestamp": obj.get("timestamp"),
            "domain_id": obj.get("domain_id"),
            "url_id": obj.get("url_id")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.subscription_plan import SubscriptionPlan
from typing import Optional, Set
from typing_extensions import Self

class UserResponse(BaseModel):
    """
    UserResponse
    """ # noqa: E501
    user_id: StrictStr = Field(description="User ID")
    email: StrictStr = Field(description="Email of the user")
    username: StrictStr = Field(description="Name of the user")
    is_active: Optional[StrictBool] = None
    avatar_url: Optional[StrictStr] = None
    api_key_workspace_id: Optional[StrictStr] = None
    product_plans: Optional[Dict[str, SubscriptionPlan]] = None
    __properties: ClassVar[List[str]] = ["user_id", "email", "username", "is_active", "avatar_url", "api_key_workspace_id", "product_plans"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if is_active (nullable) is None
        # and model_fields_set contains the field
        if self.is_active is None and "is_active" in self.model_fields_set:
            _dict['is_active'] = None

        # set to None if avatar_url (nullable) is None
        # and model_fields_set contains the field
        if self.avatar_url is None and "avatar_url" in self.model_fields_set:
            _dict['avatar_url'] = None

        # set to None if api_key_workspace_id (nullable) is None
        # and model_fields_set contains the field
        if self.api_key_workspace_id is None and "api_key_workspace_id" in self.model_fields_set:
            _dict['api_key_workspace_id'] = None

        # set to None if product_plans (nullable) is None
        # and model_fields_set contains the field
        if self.product_plans is None and "product_plans" in self.model_fields_set:
            _dict['product_plans'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "user_id": obj.get("user_id"),
            "email": obj.get("email"),
            "username": obj.get("username"),
            "is_active": obj.get("is_active"),
            "avatar_url": obj.get("avatar_url"),
            "api_key_workspace_id": obj.get("api_key_workspace_id"),
            "product_plans": dict((_k, _v) for _k, _v in obj.get("product_plans").items()) if obj.get("product_plans") is not None else None
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from flowhunt.models.tracking_event_data import TrackingEventData
from typing import Optional, Set
from typing_extensions import Self

class TrackingEventCreateRequest(BaseModel):
    """
    TrackingEventCreateRequest
    """ # noqa: E501
    event_name: StrictStr = Field(description="The name of the event")
    unique_id: Optional[StrictStr] = None
    event_value: Optional[Union[StrictFloat, StrictInt]] = None
    currency: Optional[StrictStr] = None
    event_data: Optional[List[TrackingEventData]] = None
    link_ids: Optional[List[StrictStr]] = None
    valid_until: Optional[datetime] = None
    conversion_action_id: Optional[StrictStr] = None
    include_in_conversions_metric: Optional[StrictBool] = None
    url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["event_name", "unique_id", "event_value", "currency", "event_data", "link_ids", "valid_until", "conversion_action_id", "include_in_conversions_metric", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TrackingEventCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in event_data (list)
        _items = []
        if self.event_data:
            for _item_event_data in self.event_data:
                if _item_event_data:
                    _items.append(_item_event_data.to_dict())
            _dict['event_data'] = _items
        # set to None if unique_id (nullable) is None
        # and model_fields_set contains the field
        if self.unique_id is None and "unique_id" in self.model_fields_set:
            _dict['unique_id'] = None

        # set to None if event_value (nullable) is None
        # and model_fields_set contains the field
        if self.event_value is None and "event_value" in self.model_fields_set:
            _dict['event_value'] = None

        # set to None if currency (nullable) is None
        # and model_fields_set contains the field
        if self.currency is None and "currency" in self.model_fields_set:
            _dict['currency'] = None

        # set to None if event_data (nullable) is None
        # and model_fields_set contains the field
        if self.event_data is None and "event_data" in self.model_fields_set:
            _dict['event_data'] = None

        # set to None if link_ids (nullable) is None
        # and model_fields_set contains the field
        if self.link_ids is None and "link_ids" in self.model_fields_set:
            _dict['link_ids'] = None

        # set to None if valid_until (nullable) is None
        # and model_fields_set contains the field
        if self.valid_until is None and "valid_until" in self.model_fields_set:
            _dict['valid_until'] = None

        # set to None if conversion_action_id (nullable) is None
        # and model_fields_set contains the field
        if self.conversion_action_id is None and "conversion_action_id" in self.model_fields_set:
            _dict['conversion_action_id'] = None

        # set to None if include_in_conversions_metric (nullable) is None
        # and model_fields_set contains the field
        if self.include_in_conversions_metric is None and "include_in_conversions_metric" in self.model_fields_set:
            _dict['include_in_conversions_metric'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TrackingEventCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "event_name": obj.get("event_name"),
            "unique_id": obj.get("unique_id"),
            "event_value": obj.get("event_value"),
            "currency": obj.get("currency"),
            "event_data": [TrackingEventData.from_dict(_item) for _item in obj["event_data"]] if obj.get("event_data") is not None else None,
            "link_ids": obj.get("link_ids"),
            "valid_until": obj.get("valid_until"),
            "conversion_action_id": obj.get("conversion_action_id"),
            "include_in_conversions_metric": obj.get("include_in_conversions_metric"),
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_session_view_search_request import FlowSessionViewSearchRequest

class TestFlowSessionViewSearchRequest(unittest.TestCase):
    """FlowSessionViewSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowSessionViewSearchRequest:
        """Test FlowSessionViewSearchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowSessionViewSearchRequest`
        """
        model = FlowSessionViewSearchRequest()
        if include_optional:
            return FlowSessionViewSearchRequest(
                chatbot_id = '',
                flow_id = '',
                tags = [
                    ''
                    ],
                limit = 56,
                created_at_filter = {
                    'key' : null
                    },
                last_message_at_filter = {
                    'key' : null
                    },
                duration_filter = {
                    'key' : null
                    },
                msg_count_filter = {
                    'key' : null
                    },
                credits_filter = {
                    'key' : null
                    },
                chatbot_name = '',
                flow_name = '',
                ipaddress_filter = {
                    'key' : null
                    },
                pagination = flowhunt.models.pagination.Pagination(
                    sorting_key_value = '', 
                    scroll_id = '', )
            )
        else:
            return FlowSessionViewSearchRequest(
        )
        """

    def testFlowSessionViewSearchRequest(self):
        """Test FlowSessionViewSearchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.fine_tunings_api import FineTuningsApi


class TestFineTuningsApi(unittest.TestCase):
    """FineTuningsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FineTuningsApi()

    def tearDown(self) -> None:
        pass

    def test_create_image_ft(self) -> None:
        """Test case for create_image_ft

        Create Image Ft
        """
        pass

    def test_delete_file_ft(self) -> None:
        """Test case for delete_file_ft

        Delete File Ft
        """
        pass

    def test_delete_image_ft(self) -> None:
        """Test case for delete_image_ft

        Delete Image Ft
        """
        pass

    def test_generate_image_prompt(self) -> None:
        """Test case for generate_image_prompt

        Generate Image Prompt
        """
        pass

    def test_generate_images(self) -> None:
        """Test case for generate_images

        Generate Images
        """
        pass

    def test_get_file_ft(self) -> None:
        """Test case for get_file_ft

        Get File Ft
        """
        pass

    def test_get_inference_results(self) -> None:
        """Test case for get_inference_results

        Get Inference Results
        """
        pass

    def test_handle_replicate_webhook(self) -> None:
        """Test case for handle_replicate_webhook

        Handle Replicate Webhook
        """
        pass

    def test_search_image_fts(self) -> None:
        """Test case for search_image_fts

        Search Image Fts
        """
        pass

    def test_search_inference_history(self) -> None:
        """Test case for search_inference_history

        Search Inference History
        """
        pass

    def test_update_image_ft(self) -> None:
        """Test case for update_image_ft

        Update Image Ft
        """
        pass

    def test_upload_image_ft(self) -> None:
        """Test case for upload_image_ft

        Upload Image Ft
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TaskStatus(str, Enum):
    """
    TaskStatus
    """

    """
    allowed enum values
    """
    PENDING = 'PENDING'
    SUCCESS = 'SUCCESS'
    FAILURE = 'FAILURE'
    RETRY = 'RETRY'
    REVOKED = 'REVOKED'
    RECEIVED = 'RECEIVED'
    STARTED = 'STARTED'
    IGNORED = 'IGNORED'
    REJECTED = 'REJECTED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TaskStatus from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.media_api import MediaApi


class TestMediaApi(unittest.TestCase):
    """MediaApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MediaApi()

    def tearDown(self) -> None:
        pass

    def test_get_transcript(self) -> None:
        """Test case for get_transcript

        Get Transcript
        """
        pass

    def test_get_transcript_result(self) -> None:
        """Test case for get_transcript_result

        Get Transcript Result
        """
        pass

    def test_get_youtube_transcript(self) -> None:
        """Test case for get_youtube_transcript

        Get Youtube Transcript
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.observability_driver_api import ObservabilityDriverApi


class TestObservabilityDriverApi(unittest.TestCase):
    """ObservabilityDriverApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ObservabilityDriverApi()

    def tearDown(self) -> None:
        pass

    def test_activate_langfuse_observability_driver(self) -> None:
        """Test case for activate_langfuse_observability_driver

        Activate Langfuse Observability Driver
        """
        pass

    def test_delete_observability_driver(self) -> None:
        """Test case for delete_observability_driver

        Delete Observability Driver
        """
        pass

    def test_get_observability_driver(self) -> None:
        """Test case for get_observability_driver

        Get Observability Driver
        """
        pass

    def test_get_observability_driver_workspace(self) -> None:
        """Test case for get_observability_driver_workspace

        Get Observability Driver Workspace
        """
        pass

    def test_update_langfuse_observability_driver(self) -> None:
        """Test case for update_langfuse_observability_driver

        Update Langfuse Observability Driver
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictStr
from typing import List
from flowhunt.models.flow_assistant_apply_reject_changes_request import FlowAssistantApplyRejectChangesRequest
from flowhunt.models.flow_assistant_invoke_request import FlowAssistantInvokeRequest
from flowhunt.models.flow_assistant_session_create_request import FlowAssistantSessionCreateRequest
from flowhunt.models.flow_detail_response import FlowDetailResponse
from flowhunt.models.flow_session_event import FlowSessionEvent
from flowhunt.models.flow_session_invocation_response import FlowSessionInvocationResponse
from flowhunt.models.flow_session_response import FlowSessionResponse

from flowhunt.api_client import ApiClient, RequestSerialized
from flowhunt.api_response import ApiResponse
from flowhunt.rest import RESTResponseType


class FlowAssistantApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def apply_flow_assistant_changes(
        self,
        workspace_id: StrictStr,
        flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FlowDetailResponse:
        """Apply Flow Assistant Changes


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_apply_reject_changes_request: (required)
        :type flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._apply_flow_assistant_changes_serialize(
            workspace_id=workspace_id,
            flow_assistant_apply_reject_changes_request=flow_assistant_apply_reject_changes_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowDetailResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def apply_flow_assistant_changes_with_http_info(
        self,
        workspace_id: StrictStr,
        flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FlowDetailResponse]:
        """Apply Flow Assistant Changes


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_apply_reject_changes_request: (required)
        :type flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._apply_flow_assistant_changes_serialize(
            workspace_id=workspace_id,
            flow_assistant_apply_reject_changes_request=flow_assistant_apply_reject_changes_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowDetailResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def apply_flow_assistant_changes_without_preload_content(
        self,
        workspace_id: StrictStr,
        flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Apply Flow Assistant Changes


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_apply_reject_changes_request: (required)
        :type flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._apply_flow_assistant_changes_serialize(
            workspace_id=workspace_id,
            flow_assistant_apply_reject_changes_request=flow_assistant_apply_reject_changes_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowDetailResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _apply_flow_assistant_changes_serialize(
        self,
        workspace_id,
        flow_assistant_apply_reject_changes_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workspace_id is not None:
            
            _query_params.append(('workspace_id', workspace_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if flow_assistant_apply_reject_changes_request is not None:
            _body_params = flow_assistant_apply_reject_changes_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/flow_assistants/apply_changes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def create_flow_assistant_session(
        self,
        workspace_id: StrictStr,
        flow_assistant_session_create_request: FlowAssistantSessionCreateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FlowSessionResponse:
        """Create Flow Assistant Session


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_session_create_request: (required)
        :type flow_assistant_session_create_request: FlowAssistantSessionCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_flow_assistant_session_serialize(
            workspace_id=workspace_id,
            flow_assistant_session_create_request=flow_assistant_session_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FlowSessionResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_flow_assistant_session_with_http_info(
        self,
        workspace_id: StrictStr,
        flow_assistant_session_create_request: FlowAssistantSessionCreateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FlowSessionResponse]:
        """Create Flow Assistant Session


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_session_create_request: (required)
        :type flow_assistant_session_create_request: FlowAssistantSessionCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_flow_assistant_session_serialize(
            workspace_id=workspace_id,
            flow_assistant_session_create_request=flow_assistant_session_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FlowSessionResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_flow_assistant_session_without_preload_content(
        self,
        workspace_id: StrictStr,
        flow_assistant_session_create_request: FlowAssistantSessionCreateRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Flow Assistant Session


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_session_create_request: (required)
        :type flow_assistant_session_create_request: FlowAssistantSessionCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_flow_assistant_session_serialize(
            workspace_id=workspace_id,
            flow_assistant_session_create_request=flow_assistant_session_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "FlowSessionResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_flow_assistant_session_serialize(
        self,
        workspace_id,
        flow_assistant_session_create_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workspace_id is not None:
            
            _query_params.append(('workspace_id', workspace_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if flow_assistant_session_create_request is not None:
            _body_params = flow_assistant_session_create_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/flow_assistants/create',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def invoke_flow_assistant_response(
        self,
        session_id: StrictStr,
        flow_assistant_invoke_request: FlowAssistantInvokeRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FlowSessionInvocationResponse:
        """Invoke Flow Assistant Response


        :param session_id: (required)
        :type session_id: str
        :param flow_assistant_invoke_request: (required)
        :type flow_assistant_invoke_request: FlowAssistantInvokeRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invoke_flow_assistant_response_serialize(
            session_id=session_id,
            flow_assistant_invoke_request=flow_assistant_invoke_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowSessionInvocationResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def invoke_flow_assistant_response_with_http_info(
        self,
        session_id: StrictStr,
        flow_assistant_invoke_request: FlowAssistantInvokeRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FlowSessionInvocationResponse]:
        """Invoke Flow Assistant Response


        :param session_id: (required)
        :type session_id: str
        :param flow_assistant_invoke_request: (required)
        :type flow_assistant_invoke_request: FlowAssistantInvokeRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invoke_flow_assistant_response_serialize(
            session_id=session_id,
            flow_assistant_invoke_request=flow_assistant_invoke_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowSessionInvocationResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def invoke_flow_assistant_response_without_preload_content(
        self,
        session_id: StrictStr,
        flow_assistant_invoke_request: FlowAssistantInvokeRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Invoke Flow Assistant Response


        :param session_id: (required)
        :type session_id: str
        :param flow_assistant_invoke_request: (required)
        :type flow_assistant_invoke_request: FlowAssistantInvokeRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invoke_flow_assistant_response_serialize(
            session_id=session_id,
            flow_assistant_invoke_request=flow_assistant_invoke_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowSessionInvocationResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _invoke_flow_assistant_response_serialize(
        self,
        session_id,
        flow_assistant_invoke_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if session_id is not None:
            _path_params['session_id'] = session_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if flow_assistant_invoke_request is not None:
            _body_params = flow_assistant_invoke_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/flow_assistants/{session_id}/invoke',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def poll_flow_assistant_response(
        self,
        session_id: StrictStr,
        from_timestamp: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[FlowSessionEvent]:
        """Poll Flow Assistant Response


        :param session_id: (required)
        :type session_id: str
        :param from_timestamp: (required)
        :type from_timestamp: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._poll_flow_assistant_response_serialize(
            session_id=session_id,
            from_timestamp=from_timestamp,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[FlowSessionEvent]",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def poll_flow_assistant_response_with_http_info(
        self,
        session_id: StrictStr,
        from_timestamp: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[FlowSessionEvent]]:
        """Poll Flow Assistant Response


        :param session_id: (required)
        :type session_id: str
        :param from_timestamp: (required)
        :type from_timestamp: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._poll_flow_assistant_response_serialize(
            session_id=session_id,
            from_timestamp=from_timestamp,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[FlowSessionEvent]",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def poll_flow_assistant_response_without_preload_content(
        self,
        session_id: StrictStr,
        from_timestamp: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Poll Flow Assistant Response


        :param session_id: (required)
        :type session_id: str
        :param from_timestamp: (required)
        :type from_timestamp: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._poll_flow_assistant_response_serialize(
            session_id=session_id,
            from_timestamp=from_timestamp,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[FlowSessionEvent]",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _poll_flow_assistant_response_serialize(
        self,
        session_id,
        from_timestamp,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if session_id is not None:
            _path_params['session_id'] = session_id
        if from_timestamp is not None:
            _path_params['from_timestamp'] = from_timestamp
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/flow_assistants/{session_id}/invocation_response/{from_timestamp}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def reject_flow_assistant_changes(
        self,
        workspace_id: StrictStr,
        flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FlowDetailResponse:
        """Reject Flow Assistant Changes


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_apply_reject_changes_request: (required)
        :type flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reject_flow_assistant_changes_serialize(
            workspace_id=workspace_id,
            flow_assistant_apply_reject_changes_request=flow_assistant_apply_reject_changes_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowDetailResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def reject_flow_assistant_changes_with_http_info(
        self,
        workspace_id: StrictStr,
        flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FlowDetailResponse]:
        """Reject Flow Assistant Changes


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_apply_reject_changes_request: (required)
        :type flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reject_flow_assistant_changes_serialize(
            workspace_id=workspace_id,
            flow_assistant_apply_reject_changes_request=flow_assistant_apply_reject_changes_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowDetailResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def reject_flow_assistant_changes_without_preload_content(
        self,
        workspace_id: StrictStr,
        flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Reject Flow Assistant Changes


        :param workspace_id: (required)
        :type workspace_id: str
        :param flow_assistant_apply_reject_changes_request: (required)
        :type flow_assistant_apply_reject_changes_request: FlowAssistantApplyRejectChangesRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._reject_flow_assistant_changes_serialize(
            workspace_id=workspace_id,
            flow_assistant_apply_reject_changes_request=flow_assistant_apply_reject_changes_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FlowDetailResponse",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _reject_flow_assistant_changes_serialize(
        self,
        workspace_id,
        flow_assistant_apply_reject_changes_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if workspace_id is not None:
            
            _query_params.append(('workspace_id', workspace_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if flow_assistant_apply_reject_changes_request is not None:
            _body_params = flow_assistant_apply_reject_changes_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/flow_assistants/reject_changes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.workspaces_api import WorkspacesApi


class TestWorkspacesApi(unittest.TestCase):
    """WorkspacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkspacesApi()

    def tearDown(self) -> None:
        pass

    def test_add_workspace_user(self) -> None:
        """Test case for add_workspace_user

        Add Workspace User
        """
        pass

    def test_create_workspace(self) -> None:
        """Test case for create_workspace

        Create Workspace
        """
        pass

    def test_delete_workspace(self) -> None:
        """Test case for delete_workspace

        Delete Workspace
        """
        pass

    def test_delete_workspace_user(self) -> None:
        """Test case for delete_workspace_user

        Delete Workspace User
        """
        pass

    def test_get_workspace(self) -> None:
        """Test case for get_workspace

        Get Workspace
        """
        pass

    def test_search_my_workspaces(self) -> None:
        """Test case for search_my_workspaces

        Search My Workspaces
        """
        pass

    def test_search_workspace_users(self) -> None:
        """Test case for search_workspace_users

        Search Workspace Users
        """
        pass

    def test_update_workspace(self) -> None:
        """Test case for update_workspace

        Update Workspace
        """
        pass

    def test_update_workspace_user(self) -> None:
        """Test case for update_workspace_user

        Update Workspace User
        """
        pass


if __name__ == '__main__':
    unittest.main()
